//$Id: app-win.h,v 1.5 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_APP_WIN_H
#define GUIKACHU_APP_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class AppWindow;
    }
}

#include "app-res.h"

#include <gtk--/window.h>

namespace Guikachu
{
    namespace GUI
    {
	class AppWindow: public SigC::Object
	{
	    Gtk::Window            *window;
	    Resources::Application *res;

	public:
	    AppWindow (Resources::Application *res);
	    ~AppWindow ();

	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();
	};
    };
};

#endif /* !GUIKACHU_APP_WIN_H */
